flint: Fast Library for Number Theory
=====================================

Description
-----------

FLINT is a C library for doing number theory, maintained by William
Hart.

Website: http://www.flintlib.org

License
-------

FLINT is licensed GPL v2+.


Upstream Contact
----------------

-  flint-devel Gougle Group
   (http://groups.google.co.uk/group/flint-devel)
-  William Hart
